import * as moment_ from 'moment';
import { Injectable, NgModule } from '@angular/core';
import { HttpClientModule } from '@angular/common/http';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment = moment_;
/**
 * @abstract
 */
class CalendarObject {
    /**
     * @param {?} icsString
     * @return {?}
     */
    selfParse(icsString) {
        /** @type {?} */
        var firstLine = true;
        /** @type {?} */
        var subObject = false;
        /** @type {?} */
        var childObjectClass = '';
        /** @type {?} */
        var childIcsString = '';
        icsString = icsString.replace(/\n /g, "");
        for (let line of icsString.split('\n')) {
            // Current Line
            /** @type {?} */
            let sepIndex = line.indexOf(":");
            /** @type {?} */
            let property = line.substring(0, sepIndex);
            /** @type {?} */
            var value = line.substring(sepIndex + 1, line.length);
            if (value)
                value = value.slice(0, -1);
            childIcsString += line + '\n';
            // Child Object Parsing
            if ((property == 'END') && (value == childObjectClass)) {
                subObject = false;
                switch (childObjectClass) {
                    case 'VEVENT':
                        this.addChildren('VEVENT', new Event(childIcsString));
                        break;
                    case 'VJOURNAL':
                        this.addChildren('VJOURNAL', new Journal(childIcsString));
                        break;
                    case 'VTODO':
                        this.addChildren('VTODO', new Todo(childIcsString));
                        break;
                    case 'VALARM':
                        this.addChildren('VALARM', new Alarm(childIcsString));
                        break;
                    case 'VTIMEZONE':
                        this.addChildren('VTIMEZONE', new Timezones(childIcsString));
                        break;
                    case 'STANDARD':
                        this.addChildren('STANDARD', new Timezone(childIcsString));
                        break;
                    case 'DAYLIGHT':
                        this.addChildren('DAYLIGHT', new Timezone(childIcsString));
                        break;
                }
            }
            if ((property == 'BEGIN') && (!firstLine) && (!subObject)) {
                childObjectClass = value;
                childIcsString = '';
                subObject = true;
            }
            // Set the properties of current object
            else {
                this.setProperty(property, value);
            }
            // First Line
            if (firstLine) {
                firstLine = false;
            }
        }
    }
}
/**
 * @abstract
 */
class EventTodoJournalComponent extends CalendarObject {
    /**
     * @param {?} property
     * @param {?} value
     * @return {?}
     */
    setProperty(property, value) {
        switch (property) {
            case 'DTSTAMP':
                this.dtstamp = moment(value);
                break;
            case 'LAST-MODIFIED':
                this.lastmod = moment(value);
                break;
            case 'DTSTART':
                this.dtstart = moment(value);
                break;
            case 'CREATED':
                this.created = moment(value);
                break;
            case 'DESCRIPTION':
                this.description = value;
                break;
            case 'SUMMARY':
                this.summary = value;
                break;
            case 'RRULE':
                this.rrule = value;
                break;
        }
    }
}
/**
 * @abstract
 */
class EventTodoComponent extends EventTodoJournalComponent {
    constructor() {
        super();
        this.resources = new Array();
        this.alarm = new Array();
    }
    /**
     * @param {?} property
     * @param {?} value
     * @return {?}
     */
    setProperty(property, value) {
        super.setProperty(property, value);
        switch (property) {
            case 'PRIORITY':
                this.priority = value;
                break;
        }
    }
    /**
     * @param {?} cls
     * @param {?} object
     * @return {?}
     */
    addChildren(cls, object) {
        switch (cls) {
            case 'VALARM':
                this.alarm.push(object);
                break;
        }
    }
}
class Alarm extends CalendarObject {
    /**
     * @param {?} icsString
     */
    constructor(icsString) {
        super();
        this.attendee = new Array();
        this.selfParse(icsString);
    }
    /**
     * @param {?} property
     * @param {?} value
     * @return {?}
     */
    setProperty(property, value) {
        switch (property) {
            case 'ACTION':
                this.action = value;
                break;
            case 'DESCRIPTION':
                this.description = value;
                break;
            case 'TRIGGER':
                this.trigger = value;
                break;
        }
    }
    /**
     * @param {?} cls
     * @param {?} object
     * @return {?}
     */
    addChildren(cls, object) { }
}
class Event extends EventTodoComponent {
    /**
     * @param {?} icsString
     */
    constructor(icsString) {
        super();
        this.selfParse(icsString);
    }
    /**
     * @param {?} property
     * @param {?} value
     * @return {?}
     */
    setProperty(property, value) {
        super.setProperty(property, value);
        switch (property) {
            case 'DTEND':
                this.dtend = moment(value);
                break;
            case 'TRANSP':
                this.transp = value;
                break;
        }
    }
}
class Todo extends EventTodoComponent {
    /**
     * @param {?} icsString
     */
    constructor(icsString) {
        super();
        this.selfParse(icsString);
    }
    /**
     * @param {?} property
     * @param {?} value
     * @return {?}
     */
    setProperty(property, value) {
        super.setProperty(property, value);
        switch (property) {
            case 'COMPLETED':
                this.completed = value;
                break;
            case 'DUE':
                this.due = moment(value);
                break;
            case 'PERCENT':
                this.percent = value;
                break;
        }
    }
}
class Journal extends EventTodoJournalComponent {
    /**
     * @param {?} icsString
     */
    constructor(icsString) {
        super();
        this.selfParse(icsString);
    }
    /**
     * @param {?} cls
     * @param {?} object
     * @return {?}
     */
    addChildren(cls, object) { }
}
class Timezone extends CalendarObject {
    /**
     * @param {?} icsString
     */
    constructor(icsString) {
        super();
        this.selfParse(icsString);
    }
    /**
     * @param {?} property
     * @param {?} value
     * @return {?}
     */
    setProperty(property, value) {
        switch (property) {
            case 'TZNAME':
                this.tzname = value;
                break;
            case 'TZOFFSETFROM':
                this.tzoffsetfrom = value;
                break;
            case 'TZOFFSETTO':
                this.tzoffsetto = value;
                break;
        }
    }
    /**
     * @param {?} cls
     * @param {?} object
     * @return {?}
     */
    addChildren(cls, object) { }
}
class Timezones extends CalendarObject {
    /**
     * @param {?} icsString
     */
    constructor(icsString) {
        super();
        this.selfParse(icsString);
    }
    /**
     * @param {?} property
     * @param {?} value
     * @return {?}
     */
    setProperty(property, value) {
        switch (property) {
            case 'TZID':
                this.tzid = value;
                break;
        }
    }
    /**
     * @param {?} cls
     * @param {?} object
     * @return {?}
     */
    addChildren(cls, object) {
        switch (cls) {
            case 'STANDARD':
                this.standard = object;
                break;
            case 'DAYLIGHT':
                this.daylight = object;
                break;
        }
    }
}
class Calendar extends CalendarObject {
    /**
     * @param {?} icsString
     */
    constructor(icsString) {
        super();
        this.events = [];
        this.timezones = [];
        this.selfParse(icsString);
    }
    /**
     * @param {?} property
     * @param {?} value
     * @return {?}
     */
    setProperty(property, value) {
        switch (property) {
            case 'PRODID':
                this.prodid = value;
                break;
            case 'VERSION':
                this.version = value;
                break;
            case 'CALSCALE':
                this.calscale = value;
                break;
        }
    }
    /**
     * @param {?} cls
     * @param {?} object
     * @return {?}
     */
    addChildren(cls, object) {
        switch (cls) {
            case 'VEVENT':
                this.events.push(object);
                break;
            case 'VTIMEZONE':
                this.timezones.push(object);
                break;
        }
    }
    /**
     * @param {?} from
     * @param {?} to
     * @return {?}
     */
    getEvents(from, to) {
        /** @type {?} */
        var events = Array();
        for (let event of this.events) {
            if ((event.dtend >= from) && (event.dtstart <= to)) {
                events.push(event);
            }
        }
        return events;
    }
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/angular-icalendar.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class IcsParserService {
    /**
     * @param {?} ics
     * @return {?}
     */
    parseICS(ics) {
        return new Calendar(ics);
    }
}
IcsParserService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/angular-icalendar.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AngularIcalendarModule {
}
AngularIcalendarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [
                    HttpClientModule
                ],
                providers: [
                    IcsParserService
                ],
                exports: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: angular-icalendar.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { IcsParserService, AngularIcalendarModule };

//# sourceMappingURL=angular-icalendar.js.map